Class: MParticle::Batch

Inherits:
Object
  • Object
show all
Defined in:
lib/mparticle/models/batch.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Batch

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/mparticle/models/batch.rb', line 137

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}){|(k,v), h| h[k.to_sym] = v}

  if attributes.has_key?(:'events')
    if (value = attributes[:'events']).is_a?(Array)
      self.events = value
    end
  end

  if attributes.has_key?(:'source_request_id')
    self.source_request_id = attributes[:'source_request_id']
  end

  if attributes.has_key?(:'environment')
    self.environment = attributes[:'environment']
  end

  if attributes.has_key?(:'ip')
    self.ip = attributes[:'ip']
  end

  if attributes.has_key?(:'schema_version')
    self.schema_version = attributes[:'schema_version']
  end

  if attributes.has_key?(:'device_info')
    self.device_info = attributes[:'device_info']
  end

  if attributes.has_key?(:'application_info')
    self.application_info = attributes[:'application_info']
  end

  if attributes.has_key?(:'user_attributes')
    self.user_attributes = attributes[:'user_attributes']
  end

  if attributes.has_key?(:'deleted_user_attributes')
    if (value = attributes[:'deleted_user_attributes']).is_a?(Array)
      self.deleted_user_attributes = value
    end
  end

  if attributes.has_key?(:'user_identities')
    self.user_identities = attributes[:'user_identities']
  end

  if attributes.has_key?(:'api_key')
    self.api_key = attributes[:'api_key']
  end

  if attributes.has_key?(:'mpid')
    self.mpid = attributes[:'mpid']
  end

  if attributes.has_key?(:'mp_deviceid')
    self.mp_deviceid = attributes[:'mp_deviceid']
  end

end

Instance Attribute Details

#api_keyObject

Returns the value of attribute api_key.



28
29
30
# File 'lib/mparticle/models/batch.rb', line 28

def api_key
  @api_key
end

#application_infoObject

Returns the value of attribute application_info.



18
19
20
# File 'lib/mparticle/models/batch.rb', line 18

def application_info
  @application_info
end

Returns the value of attribute consent_state.



26
27
28
# File 'lib/mparticle/models/batch.rb', line 26

def consent_state
  @consent_state
end

#deleted_user_attributesObject

Returns the value of attribute deleted_user_attributes.



22
23
24
# File 'lib/mparticle/models/batch.rb', line 22

def deleted_user_attributes
  @deleted_user_attributes
end

#device_infoObject

Returns the value of attribute device_info.



16
17
18
# File 'lib/mparticle/models/batch.rb', line 16

def device_info
  @device_info
end

#environmentObject

Returns the value of attribute environment.



10
11
12
# File 'lib/mparticle/models/batch.rb', line 10

def environment
  @environment
end

#eventsObject

Returns the value of attribute events.



6
7
8
# File 'lib/mparticle/models/batch.rb', line 6

def events
  @events
end

#ipObject

Returns the value of attribute ip.



12
13
14
# File 'lib/mparticle/models/batch.rb', line 12

def ip
  @ip
end

#mp_deviceidObject

Returns the value of attribute mp_deviceid.



32
33
34
# File 'lib/mparticle/models/batch.rb', line 32

def mp_deviceid
  @mp_deviceid
end

#mpidObject

Returns the value of attribute mpid.



30
31
32
# File 'lib/mparticle/models/batch.rb', line 30

def mpid
  @mpid
end

#schema_versionObject

Returns the value of attribute schema_version.



14
15
16
# File 'lib/mparticle/models/batch.rb', line 14

def schema_version
  @schema_version
end

#source_request_idObject

Returns the value of attribute source_request_id.



8
9
10
# File 'lib/mparticle/models/batch.rb', line 8

def source_request_id
  @source_request_id
end

#user_attributesObject

Returns the value of attribute user_attributes.



20
21
22
# File 'lib/mparticle/models/batch.rb', line 20

def user_attributes
  @user_attributes
end

#user_identitiesObject

Returns the value of attribute user_identities.



24
25
26
# File 'lib/mparticle/models/batch.rb', line 24

def user_identities
  @user_identities
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/mparticle/models/batch.rb', line 97

def self.attribute_map
  {
    :'events' => :'events',
    :'source_request_id' => :'source_request_id',
    :'environment' => :'environment',
    :'ip' => :'ip',
    :'schema_version' => :'schema_version',
    :'device_info' => :'device_info',
    :'application_info' => :'application_info',
    :'user_attributes' => :'user_attributes',
    :'consent_state' => :'consent_state',
    :'deleted_user_attributes' => :'deleted_user_attributes',
    :'user_identities' => :'user_identities',
    :'api_key' => :'api_key',
    :'mpid' => :'mpid',
    :'mp_deviceid' => :'mp_deviceid'
  }
end

.swagger_typesObject

Attribute type mapping.



117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/mparticle/models/batch.rb', line 117

def self.swagger_types
  {
    :'events' => :'Array<EventBase>',
    :'source_request_id' => :'String',
    :'environment' => :'String',
    :'ip' => :'String',
    :'schema_version' => :'Integer',
    :'device_info' => :'DeviceInformation',
    :'application_info' => :'ApplicationInformation',
    :'user_attributes' => :'Object',
    :'deleted_user_attributes' => :'Array<String>',
    :'user_identities' => :'UserIdentities',
    :'api_key' => :'String',
    :'mpid' => :'Integer',
    :'mp_deviceid' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/mparticle/models/batch.rb', line 233

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      events == o.events &&
      source_request_id == o.source_request_id &&
      environment == o.environment &&
      ip == o.ip &&
      schema_version == o.schema_version &&
      device_info == o.device_info &&
      application_info == o.application_info &&
      user_attributes == o.user_attributes &&
      deleted_user_attributes == o.deleted_user_attributes &&
      user_identities == o.user_identities &&
      api_key == o.api_key &&
      mpid == o.mpid &&
      mp_deviceid == o.mp_deviceid
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/mparticle/models/batch.rb', line 287

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = MParticle.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



353
354
355
356
357
358
359
360
361
362
363
364
365
# File 'lib/mparticle/models/batch.rb', line 353

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map{ |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/mparticle/models/batch.rb', line 266

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map{ |v| _deserialize($1, v) } )
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


253
254
255
# File 'lib/mparticle/models/batch.rb', line 253

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



259
260
261
# File 'lib/mparticle/models/batch.rb', line 259

def hash
  [events, source_request_id, environment, ip, schema_version, device_info, application_info, user_attributes, deleted_user_attributes, user_identities, api_key, mpid, mp_deviceid].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properies with the reasons



203
204
205
206
207
208
209
210
# File 'lib/mparticle/models/batch.rb', line 203

def list_invalid_properties
  invalid_properties = Array.new
  if @environment.nil?
    invalid_properties.push("invalid value for 'environment', environment cannot be nil.")
  end

  return invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



333
334
335
# File 'lib/mparticle/models/batch.rb', line 333

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



339
340
341
342
343
344
345
346
347
# File 'lib/mparticle/models/batch.rb', line 339

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



327
328
329
# File 'lib/mparticle/models/batch.rb', line 327

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



214
215
216
217
218
219
# File 'lib/mparticle/models/batch.rb', line 214

def valid?
  return false if @environment.nil?
  environment_validator = EnumAttributeValidator.new('String', ["production", "development"])
  return false unless environment_validator.valid?(@environment)
  return true
end